# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import bs4 as BeautifulSoup

# Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
package_name = 'seadrive-gui'


def install():
    # Installing the package
    print('Installing %s' % package_name)
    run('sudo wget https://linux-clients.seafile.com/seafile.asc -O /usr/share/keyrings/seafile-keyring.asc')
    run('sudo bash -c "echo \'deb [arch=amd64 signed-by=/usr/share/keyrings/seafile-keyring.asc] https://linux-clients.seafile.com/seadrive-deb/buster/ stable main \' > /etc/apt/sources.list.d/seadrive.list"')
    install_apt(package_name)


def uninstall():
    # Uninstalling the package
    print('Uninstalling %s' % package_name)
    uninstall_apt(package_name)




def update_package():
    result = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()

    url = 'https://manual.seafile.com/changelog/drive-client-changelog/'
    # Getting latest version from official website

    for u in bs_find_all(url,'li', proxies=proxies):
        if '[Linux]' in u.text:
            previous_element = u.previous_element
            good_version = False
            while(not good_version):
                if previous_element.name =='h3':
                    latest_version = previous_element.text.split(' ')[0] 
                    good_version=True 
                else:
                    previous_element = previous_element.previous_element
            
    print('Latest Version %s' % latest_version)

    # changing version of the package
    if Version(latest_version) != control.get_software_version():
        result = True
    control.version = '%s-%s' % (latest_version, control.version.split('-', 1)[-1])
    #control.set_software_version(version)
    control.save_control_to_wapt()

    # deleting outdated binaries
    remove_outdated_binaries(latest_version)

    # validating or not update-package-sources
    return result



